# Dev Container

[Dev Containers](https://containers.dev) allow for a fully isolated development environment tailored to specific project needs. This is particularly useful for ensuring all dependencies are installed and consistent across different development machines.

## Open the Benchmark in a Dev Container

To simplify the process of building and opening the repository as a Dev Container in Visual Studio Code (VS Code), you can run the [`.devcontainer/open.bash`](https://github.com/AndrejOrsula/space_robotics_bench/blob/main/.devcontainer/open.bash) that automates the process.

```bash
.devcontainer/open.bash
```

## Modify the Dev Container

You can also customize the included [`.devcontainer/devcontainer.json`](https://github.com/AndrejOrsula/space_robotics_bench/blob/main/.devcontainer/devcontainer.json) configuration to suit your specific development requirements.
